# Built-in application resources

## Attribution

Video file `camera.mp4` derived from original [face-demographics-walking-and-pause.mp4](https://github.com/intel-iot-devkit/sample-videos) by [Intel® IoT](https://software.intel.com/content/www/us/en/develop/topics/iot.html) is licensed under [CC BY 4.0](https://github.com/intel-iot-devkit/sample-videos/blob/master/LICENSE).